# Comparison 🟢🟡🟠🔴

| ByDefault             | Shopyo     | Django     | Masonite   |
|-----------------------|------------|------------|------------|
| Templating            | Jinja      | Own        | Jinja      |
| ORM                   | SQlAlchemy | Home Grown | Home Grown |
| Modularity            | 🟢          | 🟡          | 🟠          |
| Migrations            | 🟢          | 🟢          | 🟢          |
| Auth                  | 🟢          | 🟢          | 🟢          |
| Scaffolding           | 🟡          | 🟠          | 🟢          |
| Mail                  | 🟢          | 🟢          | 🟢          |
| Dashboard             | 🟢          | 🟢          | 🟠          |
| Extend Command        | 🟢          | 🟢          | 🟢          |
| Static                | 🟠          | 🟠          | 🟢          |
| Packages              | 🔴          | 🟢          | 🟢          |
| DB pre-populate       | 🟢          | 🟢          | 🟠          |
| API Validation & Auth | 🔴          | 🔴          | 🟢          |
| WebSockets            | 🔴          | 🔴          | 🟢          |
| Queue                 | 🔴          | 🔴          | 🟢          |
| Testing               | 🟢          | 🟢          | 🟢          |
| Project Docs*         | 🟢          | 🔴          | 🔴          |
| Internationalisation  | 🔴          | 🟢          | 🔴          |
| Caching               | 🔴          | 🟢          | 🟢          |
